package java.security.cert;

import sun.misc.HexDumpEncoder;
import java.io.IOException;
import sun.security.util.DerValue;

public class PolicyQualifierInfo
{
    private byte[] mEncoded;
    private String mId;
    private byte[] mData;
    private String pqiString;
    
    public PolicyQualifierInfo(byte[] array) throws IOException {
        this.mEncoded = (byte[])array.clone();
        DerValue derValue = new DerValue(this.mEncoded);
        if (derValue.tag != 48) {
            throw new IOException("Invalid encoding for PolicyQualifierInfo");
        }
        this.mId = derValue.data.getDerValue().getOID().toString();
        byte[] byteArray = derValue.data.toByteArray();
        if (byteArray == null) {
            this.mData = null;
        }
        else {
            System.arraycopy(byteArray, 0, this.mData = new byte[byteArray.length], 0, byteArray.length);
        }
        return;
    }
    
    public final String getPolicyQualifierId() {
        return this.mId;
    }
    
    public final byte[] getEncoded() {
        return (byte[])this.mEncoded.clone();
    }
    
    public final byte[] getPolicyQualifier() {
        return (this.mData == null) ? null : ((byte[])this.mData.clone());
    }
    
    @Override
    public String toString() {
        if (this.pqiString != null) {
            return this.pqiString;
        }
        HexDumpEncoder hexDumpEncoder = new HexDumpEncoder();
        StringBuffer sb = new StringBuffer();
        sb.append("PolicyQualifierInfo: [\n");
        sb.append("  qualifierID: " + this.mId + "\n");
        sb.append("  qualifier: " + ((this.mData == null) ? "null" : hexDumpEncoder.encodeBuffer(this.mData)) + "\n");
        sb.append("]");
        return this.pqiString = sb.toString();
    }
}
